graphium.utils
====================
module for utility functions

=== "Contents"
    * [Argument Checker](#argument-checker)
    * [Decorators](#decorators)
    * [Dictionary of Tensors](#dictionary-of-tensors)
    * [File System](#file-system)
    * [Hashing](#hashing)
    * [Moving Average Tracker](#moving-average-tracker)
    * [MUP](#mup)
    * [Read File](#read-file)
    * [Safe Run](#safe-run)
    * [Spaces](#spaces)
    * [Tensor](#tensor)


## Argument Checker
----------------
::: graphium.utils.arg_checker


## Decorators
----------------
::: graphium.utils.decorators


## Dictionary of Tensors
----------------
::: graphium.utils.dict_tensor


## File System
----------------
::: graphium.utils.fs


## Hashing
----------------
::: graphium.utils.hashing


## Moving Average Tracker
----------------
::: graphium.utils.moving_average_tracker


## MUP
----------------
::: graphium.utils.mup


## Read File
----------------
::: graphium.utils.read_file

## Safe Run
----------------
::: graphium.utils.safe_run


## Spaces
----------------
::: graphium.utils.spaces


## Tensor
----------------
::: graphium.utils.tensor
